@@ -80,8 +80,9 @@ class ResultsExporter(object):
 
             # construct url
             host = config_vars['data_host']
+            scheme = 'https' if config_vars['influx2_ssl'] else 'http'
             if is_ipv6(host): host = "[{}]".format(host)
-            influx_url = "https://{}:{}".format(host, config_vars['data_port'])
+            influx_url = "{}://{}:{}".format(scheme, host, config_vars['data_port'])
 
             sent_ok = self.send_results_to_influx2(gethostname(), influx_url, config_vars['influx2_token'],
                     config_vars['influx2_bucket'], config_vars['influx2_org'], results_dict, data_file, file_logger)
@@ -101,4 +102,4 @@ class ResultsExporter(object):
             return True
         else:
             # sending to reporting server failed, try spooling result as last resort
-            return self.send_results_to_spooler(config_vars, data_file, results_dict, file_logger)
\ No newline at end of file
+            return self.send_results_to_spooler(config_vars, data_file, results_dict, file_logger)
